@@ -183,6 +183,7 @@ struct _ECalendarViewClass {
 	void		(*update_query)		(ECalendarView *cal_view);
 	void		(*open_event)		(ECalendarView *cal_view);
 	void		(*paste_text)		(ECalendarView *cal_view);
+	gchar *		(*get_description_text)	(ECalendarView *cal_view);
 };
 
 GType		e_calendar_view_get_type	(void);
@@ -257,6 +258,7 @@ gboolean	e_calendar_view_get_tooltips	(const ECalendarViewEventData *data);
 void		e_calendar_view_move_tip	(GtkWidget *widget,
 						 gint x,
 						 gint y);
+void		e_calendar_view_destroy_tooltip	(ECalendarView *cal_view);
 
 gchar *		e_calendar_view_dup_component_summary
 						(ICalComponent *icomp);
