@@ -188,7 +188,6 @@ ece_memo_sensitize_widgets (ECompEditor *comp_editor,
 			    gboolean force_insensitive)
 {
 	ECompEditorMemo *memo_editor;
-	GtkWidget *widget, *edit_widget;
 	gboolean is_organizer;
 	guint32 flags;
 
@@ -200,13 +199,6 @@ ece_memo_sensitize_widgets (ECompEditor *comp_editor,
 	is_organizer = (flags & (E_COMP_EDITOR_FLAG_IS_NEW | E_COMP_EDITOR_FLAG_ORGANIZER_IS_USER)) != 0;
 	memo_editor = E_COMP_EDITOR_MEMO (comp_editor);
 
-	/* Make the Description read-only, not completely insensitive,
-	   thus it can be read and scrolled through and so on */
-	widget = e_comp_editor_property_part_string_get_real_edit_widget (E_COMP_EDITOR_PROPERTY_PART_STRING (memo_editor->priv->description));
-	edit_widget = e_comp_editor_property_part_get_edit_widget (memo_editor->priv->description);
-	gtk_text_view_set_editable (GTK_TEXT_VIEW (widget), gtk_widget_get_sensitive (edit_widget));
-	gtk_widget_set_sensitive (edit_widget, TRUE);
-
 	if (memo_editor->priv->insensitive_info_alert)
 		e_alert_response (memo_editor->priv->insensitive_info_alert, GTK_RESPONSE_OK);
 
