@@ -497,7 +497,6 @@ ece_task_sensitize_widgets (ECompEditor *comp_editor,
 {
 	ECompEditorTask *task_editor;
 	GtkAction *action;
-	GtkWidget *widget, *edit_widget;
 	gboolean is_organizer;
 	guint32 flags;
 
@@ -509,13 +508,6 @@ ece_task_sensitize_widgets (ECompEditor *comp_editor,
 	is_organizer = (flags & (E_COMP_EDITOR_FLAG_IS_NEW | E_COMP_EDITOR_FLAG_ORGANIZER_IS_USER)) != 0;
 	task_editor = E_COMP_EDITOR_TASK (comp_editor);
 
-	/* Make the Description read-only, not completely insensitive,
-	   thus it can be read and scrolled through and so on */
-	widget = e_comp_editor_property_part_string_get_real_edit_widget (E_COMP_EDITOR_PROPERTY_PART_STRING (task_editor->priv->description));
-	edit_widget = e_comp_editor_property_part_get_edit_widget (task_editor->priv->description);
-	gtk_text_view_set_editable (GTK_TEXT_VIEW (widget), gtk_widget_get_sensitive (edit_widget));
-	gtk_widget_set_sensitive (edit_widget, TRUE);
-
 	action = e_comp_editor_get_action (comp_editor, "all-day-task");
 	gtk_action_set_sensitive (action, !force_insensitive && is_organizer);
 
