@@ -763,10 +763,7 @@ client_cache_dispose (GObject *object)
 
 	g_hash_table_remove_all (priv->client_ht);
 
-	if (priv->main_context != NULL) {
-		g_main_context_unref (priv->main_context);
-		priv->main_context = NULL;
-	}
+	g_clear_pointer (&priv->main_context, g_main_context_unref);
 
 	/* Chain up to parent's dispose() method. */
 	G_OBJECT_CLASS (e_client_cache_parent_class)->dispose (object);
@@ -1147,7 +1144,7 @@ e_client_cache_get_client_sync (EClientCache *client_cache,
 			error, G_IO_ERROR,
 			G_IO_ERROR_INVALID_ARGUMENT,
 			_("Cannot create a client object from "
-			"extension name '%s'"), extension_name);
+			"extension name “%s”"), extension_name);
 		return NULL;
 	}
 
@@ -1278,7 +1275,7 @@ e_client_cache_get_client (EClientCache *client_cache,
 			simple, G_IO_ERROR,
 			G_IO_ERROR_INVALID_ARGUMENT,
 			_("Cannot create a client object from "
-			"extension name '%s'"), extension_name);
+			"extension name “%s”"), extension_name);
 		g_simple_async_result_complete_in_idle (simple);
 		goto exit;
 	}
