@@ -1536,7 +1536,7 @@ mail_reader_print_message_cb (GObject *source_object,
 
 	} else {
 		/* Set activity as completed, and keep it displayed for a few
-		 * seconds so that user can actually see the the printing was
+		 * seconds so that user can actually see the printing was
 		 * successfully finished. */
 		e_activity_set_state (activity, E_ACTIVITY_COMPLETED);
 	}
@@ -1589,7 +1589,7 @@ mail_reader_print_parse_message_cb (GObject *source_object,
 		CAMEL_FOLDER (async_context->folder),
 		e_mail_part_list_get_message_uid (part_list),
 		NULL);
-	e_filename_make_safe (export_basename);
+	e_util_make_safe_filename (export_basename);
 	e_mail_printer_set_export_filename (printer, export_basename);
 	g_free (export_basename);
 
