@@ -435,7 +435,7 @@ action_task_new_cb (GtkAction *action,
 		ECalModelComponent *comp_data;
 
 		comp_data = list->data;
-		client = g_object_ref (comp_data->client);
+		client = E_CLIENT (g_object_ref (comp_data->client));
 		g_slist_free (list);
 	}
 
@@ -979,6 +979,13 @@ static GtkRadioActionEntry task_filter_entries[] = {
 	  NULL,  /* XXX Add a tooltip! */
 	  TASK_FILTER_UNCOMPLETED_TASKS },
 
+	{ "task-filter-scheduled-tasks",
+	  NULL,
+	  N_("Scheduled Tasks"),
+	  NULL,
+	  N_("Show scheduled tasks, aka those with a Due date"),
+	  TASK_FILTER_SCHEDULED_TASKS },
+
 	{ "task-filter-next-7-days-tasks",
 	  NULL,
 	  N_("Next 7 Days’ Tasks"),
@@ -1005,7 +1012,14 @@ static GtkRadioActionEntry task_filter_entries[] = {
 	  N_("Unmatched"),
 	  NULL,
 	  NULL,  /* XXX Add a tooltip! */
-	  TASK_FILTER_UNMATCHED }
+	  TASK_FILTER_UNMATCHED },
+
+	{ "task-filter-started",
+	  NULL,
+	  N_("Started Tasks"),
+	  NULL,
+	  N_("Filters for tasks that either do not have a start date or the start date is earlier than the time the filter is selected at"),
+	  TASK_FILTER_STARTED }
 };
 
 static GtkRadioActionEntry task_search_entries[] = {
